require 'spec_helper'

module Spring
  module Commands
    describe Any do

      def make_file(name, bin_dir = "bin")
        FileUtils.touch "#{Spring.application_root_path}/#{bin_dir}/#{name}"
      end

      let(:command) { "test-command" }

      describe '.commands' do
        let(:commands) { Any.commands }

        context 'command exists in bin/' do
          it "returns the command" do
            make_file command

            expect(commands).to include command
          end
        end

        context 'command exists in script/' do
          it "returns the command" do
            make_file command, "script"

            expect(commands).to include command
          end
        end

        it "doesn't return spring-commands-any itself" do
          expect(commands).not_to include "any"
        end

        it "doesn't return built in commands" do
          binstubs = ["rails", "rake", "spring", "bundle"]
          binstubs.each {|binstub| make_file binstub }

          expect(commands).not_to include *binstubs
        end

        context 'spring-commands-rspec in Gemfile' do
          it { expect(commands).not_to include "rspec" }
        end
      end

      describe '#env' do
        context 'args == -e production' do
          let(:args) { ["-e", "production"] }

          it { expect(Any.new.env(args)).to eq "production" }
        end

        context 'args == --environment=production' do
          let(:args) { ["--environment=production"] }

          it { expect(Any.new.env(args)).to eq "production" }
        end
      end

      context 'Gem is loaded' do
        it 'register commands' do
          make_file command
          load "spring/commands/any.rb"

          expect(Spring.command?(command)).to eq true
        end
      end
    end
  end
end